#!/bin/bash
#
# Listmonk Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin

config_listmonk() {
  echo -ne "\n* Configuring /federated/apps/listmonk container.."
  spin &
  SPINPID=$!

  if [ ! -d "/federated/apps/listmonk" ]; then
    mkdir -p /federated/apps/listmonk/static /federated/apps/listmonk/data/listmonk
  fi

cat > /federated/apps/listmonk/docker-compose.yml <<EOF
version: "3.7"

services:
  listmonk:
    image: listmonk/listmonk:\${IMAGE_VERSION}
    container_name: listmonk
    hostname: listmonk.$DOMAIN
    domainname: $DOMAIN
    restart: always
    command: [sh, -c, "yes | ./listmonk --install --config config.toml && ./listmonk --config config.toml"]
    networks:
      federated:
        ipv4_address: 172.99.0.21
    env_file:
      - ./.env
    volumes:
      - ./data/listmonk/config.toml:/listmonk/config.toml
      - ./data/listmonk/static:/listmonk/static
    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.listmonk.rule=Host(\`listmonk.$DOMAIN\`)"
      - "traefik.http.routers.listmonk.entrypoints=websecure"
      - "traefik.http.routers.listmonk.tls.certresolver=letsencrypt"

networks:
  federated:
    external: true
EOF

cat > /federated/apps/listmonk/.env <<EOF
IMAGE_VERSION="v2.3.0"
TZ=Etc/UTC
EOF

cat > /federated/apps/listmonk/data/listmonk/config.toml <<EOF
[app]
address = "0.0.0.0:9000"
admin_username = "listmonk"
admin_password = "$LISTMONKPASS"

# Database.
[db]
host = "postgresql.$DOMAIN"
port = 5432
user = "listmonk"
password = "$LISTMONK_SECRET"
database = "listmonk"
ssl_mode = "verify-full"
max_open = 25
max_idle = 25
max_lifetime = "300s"
EOF
chmod 600 /federated/apps/listmonk/data/listmonk/config.toml /federated/apps/listmonk/.env
 
kill -9 $SPINPID &> /dev/null
echo -ne "done."
}
start_listmonk() {
  # Grab the container IP from docker-compose above
  SERVICE_IP=`grep ipv4_address /federated/apps/listmonk/docker-compose.yml | awk '{ print $2 }'`

  # Start service with command to make sure it's up before proceeding
  start_service "listmonk" "nc -z $SERVICE_IP 9000 &> /dev/null"

  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
